Showing posts with label Termux. Show all posts
Showing posts with label Termux. Show all posts

Tuesday, November 5, 2019

How to create a Tor SSL hidden service - Termux

Hello ladies and gentlemen, boys and girls, to tonight’s show. I will be your host. Now, let me explain to you how to create a Tor hidden service, and as a bonus, I will teach you how to set SSL to it to encrypt the connection. Enough of the bullshit, let’s roll.

Now, you will need a LOT. As always, the requirements must meet in order for it to be successful:

Packages
nginx: to deploy the web server.
tor: to act both as a proxy and a hidden service provider.
openssl to generate a self-signed SSL certificate.

Others
The Tor browser to check if your results are responsive.

Done. Now to the actions.
First of all, you gotta have to generate your SSL certificate and private key. Keep both of this in a safe and secluded directory. Use this set of commands in the correct order:

$ openssl req -x509 -newkey rsa:16384 -keyout certkey.pem -out cert.csr -days 365 -verify -set_serial 740340178739478 -sha512

$ mv certkey.pem /data/data/com.termux/files/usr/etc/nginx/

$ mv cert.csr /data/data/com.termux/files/usr/etc/nginx/

The next thing you wanna do is to go to the nginx config file and edit it with the command:
$ nano /data/data/com.termux/files/usr/etc/nginx/nginx.conf

Then, uncomment everything from line 98 to the end (HTTPS server section). Next, modify it as I say.


# HTTPS server
#
server {
listen 8443 ssl;
server_name localhost;

ssl_certificate /data/data/com.termux/files/usr/etc/nginx/cert.csr;
ssl_certificate_key /data/data/com.termux/files/usr/etc/nginx/certkey.pem;

ssl_session_cache shared:SSL:1m;
ssl_session_timeout 5m;

ssl_ciphers HIGH:!aNULL:!MD5;
ssl_prefer_server_ciphers on;

location / {
root share/nginx/html;
index index.html index.htm;
}
}

}

Next, you configure Tor to do what you want. Use the command:
$ nano /data/data/com.termux/files/usr/etc/tor/torrc

Now, locate the section where it says hidden service and modify it as I say:

############### This section is just for location-hidden services ###
## Once you have configured a hidden service, you can look at the
## contents of the file ".../hidden_service/hostname" for the address
## to tell people.
##
## HiddenServicePort x y:z says to redirect requests on port x to the
## address y:z.

HiddenServiceDir /data/data/com.termux/files/usr/var/lib/tor/hidden_service/
HiddenServicePort 443 127.0.0.1:8443

#HiddenServiceDir /data/data/com.termux/files/usr/var/lib/tor/other_hidden_service/
#HiddenServicePort 80 127.0.0.1:80
#HiddenServicePort 22 127.0.0.1:22

Now, you gotta create a directory at the specified place. Use these command in the specific order:

$ cd /data/data/com.termux/files/usr/var/lib/
$ mkdir -p tor/hidden_service/

Now the configuration is pretty much done. You just gotta do these last commands:

$ nginx
$ tor

Wait for it to finish, then use this command:
$ cat /data/data/com.termux/files/usr/var/lib/tor/hidden_service/hostname
Copy that into your clipboard.

Last step: Paste the .onion link into the Tor browser I asked you to install. You’re done here.

I hope you enjoy this tutorial. If you find it helpful, why not share it around. Always remember, Hackingarise is never responsible for any of your malicious acts. Have a nice night. Stay safe, stay ethical.

Friday, September 6, 2019

How to bruteforce website logins with Hydra

Hello everyone, this is IRISnoir from Hackingarise. Coming at you hot with another post for our blog. This time, it’s about website logins and how to crack them open. You ready? Let’s bounce.


Hacking A Rise hydra-attempts

The first thing that you wanna do before all of this is hack yourself. That’s some advice from your pal. You just have to first register and then see if you can do it with the following steps.

Attempting to hack yourself will determine if the site has a bruteforce detector. If the provider is aware and uses stuff like CaptCHA, and sends false cracks, there is definitely some security erected and that is the sign that you need to stop and start learning more.

Tools required:
Hydra to bruteforce (duhh, Captain Obvious)
Tshark to sniff the packets and determine how we should input the command.
Tsu to initiate Tshark in root mode. You also need to have your phone rooted for this.

I will now give you a step-by-step tutorial and make it as verbose as possible. But first of all, you need to connect to a wifi. Don’t use your mobile data as it will NOT work and you have to use HTTP, not HTTPS because HTTPS encrypts the packet, giving you a hard time.

Step 1: Choose the website.
In this case, I will select: testasp.vulnweb.com

Step 2: Look for the login page.
Once you located the login page, pay attention to the URL: http://testasp.vulnweb.com/Login.asp?RetURL=%2FDefault%2Easp%3F

Step 3: Utilize Tshark.
This is a hard step because it requires swiftness and precision.

First of all, enter something, anything on the login page but do not press the login button yet. Instead, leave it there and go to your terminal

The following actions will require precision.

Then, go to the terminal, enter this command:
tsudo tshark -w sniff.pcap

Then, right after that, you have to go press the login button and wait for it to load, then go right back in and stop the capture with Ctrl-C.

Now, locate the packet that mentions something about HTTP. Then memorise it’s number.
Hint: The packet I talked about will look something like this:
56 1.531393847 192.168.0.103 → 5.175.17.140 HTTP 881 POST /Login.asp?RetURL=%2FDefault%2Easp%3F HTTP/1.1 (application/x-www-form-urlencoded)
You gotta take note of that.

Now, enter this command but replace the highlighted ‘n‘ with the number of the packet that I told you to memorise.

tsudo tshark --color -VPxgWn2 -d tcp.port==1:65535,http -r sniff.pcap -a packets:n

Now you need to observe the packet. Go to the near end of the packet’s content and you should be able to see. For example, the highlighted part is the one you need to memorise:
HTML Form URL Encoded: application/x-www-form-urlencoded
Form item: "tfUName" = "boi"
Key: tfUName
Value: boi
Form item: "tfUPass" = "boi"
Key: tfUPass
Value: boi

Keep them in mind. This is crucial to the crack.

Step 4: Utilize Hydra.
The syntax for the command is:
hydra -l [INPUT USERNAME] -P [INPUT WORDLIST FILE] -e nsr -v -V [PROTOCOL]://[SERVER]/[ADDITIONAL INPUT]

My example credentials for the website logins are:
Username: IRISnoir
Password: extermux

For example, I have a file named wordlist.txt which contains:

hackingarise
boi
extermux
anime

The conditions met, now we just need to simply build the command and structure it carefully:
hydra -l IRISnoir -P wordlist.txt -e nsr -v -V http-post-form://testasp.vulnweb.com/"Login.asp?RetURL=%2FDefault%2Easp%3F:tfUName=^USER^&tfUPass=^PASS^:S=logout"

I will explain how I input the highlighted part.

First, you just put the URL and add the double brackets like so:
http://testasp.vulnweb.com/"Login.asp?RetURL=%2FDefault%2Easp%3F"

But replace the http or https in the URL with http-post-form.
http-post-form://testasp.vulnweb.com/"Login.asp?RetURL=%2FDefault%2Easp%3F"

Then remember what I told you to keep in mind? Yup, the two tfUName and tfUPass. They play a small yet big role in this if you know what I mean. Add it like what I am doing.
http-post-form://testasp.vulnweb.com/"Login.asp?RetURL=%2FDefault%2Easp%3F:tfUName=^USER^&tfUPass=^PASS^"

Finally, sprinkle a little piece of this and it’s done.
http-post-form://testasp.vulnweb.com/"Login.asp?RetURL=%2FDefault%2Easp%3F:tfUName=^USER^&tfUPass=^PASS^:S=logout"

Now, you are pretty much done. If you wanna crack other websites, you need some little modifications in the command. But it’s not really hard, just take this tutorial as a base for that and you should be good to go.

I hope you enjoy this tutorial. If so, share it with your friend whom you think will be interested in. And remember, stay safe, stay ethical as Hackingarise is never responsible for any of your malicious deeds. Have a nice day.

Friday, August 16, 2019

How to view websites with Tor router in Termux

Hello everyone~, this is IRISnoir from Hackingarise. Bringing to you another tutorial. This time about how to use Termux to look at a site anonymously with Tor.

Hacking A Rise U0JL7

This is dedicated for those who wants to do stuff in their Termux without having the need to install or purchase a VPN. Using a VPN is better than a Proxy though, but only if you can purchase them, also if you don’t want to download then another technique is through here.

I’m not gonna bother you with the details so let’s get into it.

Now, you will need these tools installed into your Termux:
– tor to initialize an anonymous circuit
– proxychains-ng to anonymize yourself with the help of Tor
– lynx to use as a Text-based web browser

Now, the first thing you need to do is to fire up Tor with:
tor
And then wait for it to finish building a Tor circuit.

Then go to your next session, use Lynx with Proxychains with:
proxychains4 lynx
And it will then check for the circuit. You can edit the configuration file of proxychains at:
$PREFIX/etc/proxychains.conf
And add more proxies to the roster to form a powerful chain. You might need to swap from strict_chain to dynamic_chain to ignore dead proxies and move on.

Now, you can enter a website URL and your IP will be hidden to the websites. Neat, right?

Again, don’t rely too much on proxies as they are not as good as a VPN. This is only for if you cannot afford or if you don’t want to download.

Question: Why don’t you make it for Google Chrome. That is much more convenient
Answer: Google Chrome Android version doesn’t support that feature where you can activate Tor as a external/plugin.

Disclaimer: This tutorial is only for educational purposes, stay ethical as Hackingarise is not responsible for any of your malicious acts or any trouble you get into.
I hope you enjoy. If you do, please share with your friends. Have a nice day. Also check this out.

Tuesday, August 6, 2019

How to capture phone-call packets

Hey guys~ This is IRISnoir from Hackingarise. Bringing to you another tutorial. This time it’s about how we can observe phone-call packets using the ultimate network sniffer: Tshark.

Hacking A Rise tshark

Now, if you are unfamiliar with it then maybe you should check this out.

Now, let me explain how this works:

Take this scenario as an example. You wanna tease/scare your friend by sending them their location. But you will need their IP. That’s why you proceed to call them with an app that has its traffic UNENCRYPTED. Then when you call them, you can intercept the traffic and observe the packets. Thus finding their IP and additional info.

You must have Tshark set up first.
tsudo tshark --color
Then it will begin to sniff packets in the air.

Now what you need to do is to call your friend.
As you are calling, the system makes a ‘request’ to call the target.
Then, as the target approves the call and picks up. It sends a reply back. Keep that in mind. It will appear as a handshake reply.

Notice that at the source – destination part.
Let’s say your IP is 192.168.1.69
And your friend’s IP is 69.133.74.20

When the request packet is sent, it appear as something like this:
192.168.1.69 -> 69.133.74.20 WireGuard Handshake Request

And if your friend picks up, it appears as something like this:
69.133.74.20 -> 192.168.1.69 WireGuard Handshake Reply

Then you can extract the IP then track it.

Thank you for taking your time to read. If you find this helpful, why not share. Have a nice day. Remember, stay ethical as Hackingarise is not responsible for any of your malicious acts. Once again, thank you for reading and being a part of our community.

Monday, July 29, 2019

How to block DNS queries with only 1 config file

Hello everyone, this is IRISnoir from Hackingarise. Bringing to you another tutorial. Today, I will discuss about DNS query blocking.

Hacking A Rise rtaImage?eid=ka10g000000DABT&feoid=00N0g000003VPSv&refid=0EM0g000001Aef6

But first, if you don’t know what DNS is or what they even mean, you should take a look at this. Also read this too if you want to understand what I’m babbling about.

Now, Malwares can use this to their advantage if you don’t know how to self secure. Luckily, this is why I am here, as a friend, to help you.

Now, what you need to do is to edit this configuration file:
/etc/hosts
Yes. This bad boy right here.

But before that, the requirements must meet:
– R0OT privilege
– Mounted READ-WRITE on /SYSTEM
– A text editor (Captain obvious)
And that’s about it. But missing any of these will lead to failure.

First, getting Root privilege is relatively easy.
Next, mounting read-write is with this command:
mount -o rw,remount /system
If you want to mount it back to read-only then use:
mount -o ro,remount /system

You need root and /system mounted read-write in order to edit this file.

If the requirements meet, you can edit the file:
Use your text editor on /etc/hosts

And no, not /data/data/com.termux/files/usr/etc

After opening the editor, you can see:
127.0.0.1 localhost
What you wanna do to secure yourself from bad places is to add:
0.0.0.0 example.com

Now, for example, example.com is a bad, bad place that will do something malicious to you if you enter it. You can do this to secure yourself from it. When you accidentally press it with your fat fingers, it won’t do anything or give a virus.

The /etc/hosts file will always be read before a DNS query is made. The system will personally conduct it. If a DNS query is approved, you can view the site and vice versa, but if it is denied, the site will look like it’s not even alive and up and you will be presumed dead to them.

System: NEXT!
youtube.com: Can I come in?
System: SURE, HAVE A NICE DAY WITH OUR USER.

System: NEXT!
serveo.net: Can I come in?
System: ENTRY DENIED, GET LOST!

I hope that you find this useful. If you do, why not share it with your friends. Remember, stay safe and ethical as we are NOT responsible for any of your malicious acts.

Friday, July 26, 2019

How to use Nmap for network scanning

Hello, this is IRISnoir from Hackingarise. Bringing to you another tutorial.

Today we will be discussing about one of the most essential steps in hacking: Scanning, and it’s representative, Nmap.

Hacking A Rise nmap5-samplescan-706x964

Now, hacking has 5 phases:
– Reconnaissance
– Scanning
– Gaining access
– Maintaining access
– Covering tracks
We will focus on the scanning phase.

Scanning refers to the technique used by hackers to uncover vulnerabilities in a system. Once a flaw is detected, the hacker can proceed to use it to their advantage to compromise a system.

Let’s take a real-life scenario as an example.
You are a burglar, and you wish to rob someone. But you need info about them and their security level. This is the part where you scan them. You look out for places that you can enter safely and quickly into and out of their house, also have an eye out for dogs, security cameras, etc.. In order not to alert the owner in any way as you break in.
DISCLAIMER: Don’t take this as advice for breaking and stealing as it is illegal and can land you in jail.

Now, you get the gist of how it works, we go to the tool and it’s usage.

Brief description of it’s usage:
The tool’s name is Nmap, as you can see in the title. It is a network mapper which enables you to map your whole network or an IP or domain. This includes finding open ports, looking for vulnerabilities, scanning your network, etc..

Now you will want to open the help menu:
nmap -h
Don’t worry, it’s not as hard as you would think. In fact, it’s really easy.

Let’s try to perform those network scans.

The network scan:
First you want to connect to your network by accessing a Wifi.
Then use:
ifconfig
Then go to the wlan0 section, find your IP address. And remember this part: 192.168.X.X
Now fill in this command:
nmap 192.168.X.0/24
Replace the “X” in the IP with the value I told you to remember.
It will proceed to sweep the network for any online hosts, then find port. You can fill in extra commands to make it stronger and scan better and more. Don’t worry, it’s only hard if you make it seem so.

The firewall evading scan technique:
Usually, hosts have firewalls to keep their ports to themselves. Even though that is the case, they do need to filter all kinds of packets. And you only need one single flaw to be discovered.

Firewall filtered ports will appear as “filtered” in the scan report. You need to select the right packet type to do the job. The packets range from TCP SYN (-sS), Connect()(-sT) to FIN(-sF), TCP Null(-sN) and more. The advanced packets do need root to work though. You can use:
tsudo nmap -sF 192.168.X.0/24
For example, it scans the network via FIN packets so as to dodge firewall. If it succeeds, hooray. If it fails, try another packet type. If all fails, then sad for you.

You can learn all about Nmap at its homepage.

I hope you enjoy this tutorial. If you like, please share with your friend. And remember, stay ethical as we aren’t responsible for any of your malicious acts. Thank you and goodbye.

Sunday, July 21, 2019

How to use Radare2 - Reverse engineering tool

Hello everybody~~

This is IRISnoir from hackingarise. Bringing to you another Termux tutorial. Today we’ll be discussing about the handy-dandy reverse engineering toolkit, Radare2.

Hacking A Rise graph

Now, a brief description of it’s usage, shall we?
Radare2 is a very handy reverse engineering tool. It can be used to analyze some CRACKME stuff and solve them good. It’s use is complex and sophisticated. But it is also very interesting and unique. Not to mention one of the most useful tool I’ve seen besides Metasploit and other. You can also use it to analyze and confirm malware.

Now, it’s installation and usage:

To install it, just casually use:
pkg install radare2

It has a LOT of tool based on it.
I’m going to break down each one.

First tool is definitely:
radare2
The main tool of the whole project. It’s alias is:
r2
This can be used as a hexadecimal editor, disasembler and debugger. That’s the shortened description of it’s usage.

Next tool is:
r2agent
Which can let you tune in with your browser and do your job on it.

Now, we keep flowing with the tools list. Next up will be:
rahash2
This is a block-based hashing utility. You can use it to calculate, check, and view the hash value of a file.

Keep going, you can see:
rax2
This lets you convert between positive and negative integer, float, octal, binary and hexadecimal values.

Next, there is:
rabin2
This can be used to extract all info from a file, script, programs, etc.. This includes compiler info, programming language used, class, etc..

I hope you are keeping up, because next on our list is:
rarun2
This can lend you a hand in running scripts and programs. Activating a script or program with this tool will enable you to run them in exotic environments. How convenient.

Keep up with the list, we got:
rasm2
This is a assembler and disassembler for many architectures. Can assemble and disassemble files and hexpair strings.

Next up, there is:
r2pm
A package manager used to install, uninstall, update packages and discover plugins that is related to radare2.

Keep going, we have:
radiff2
This is a binary diffing utility. Implements and supports many algorithms. It will analyze and compare 2 files in a hash algorithm and print the results.

Another one:
rafind2
This is a tool that help you find byte patterns in files.

We are almost done, next tool is:
ragg2
This is a frontend for r_egg. This tool will compile programs written in high-level language into convenient sized binaries for x86, x86-64 and ARM.

Final command:
r2p
It will let you run r2 commands and pipe via r2pipe.

It will take me ages to instruct you on how to use this tool. Fortunately, I found a perfect PDF that can help.

Click here to download the PDF

Now, my sincerest comments. Since the Radare2 project has a lot of tools and all of them are equally helpful, it has gained a special place in my heart.

I hope you enjoy my tutorial. If so, please share it with your friends. And remember, stay ethical as we are not responsible for any of your malicious acts or any trouble you get into. Thank you. Have a nice day.

Wednesday, July 17, 2019

How to use Weechat, the IRC client in Termux

Hello everyone~~

This is IRISnoir from Hackingarise. Bringing another Termux tutorial. This time about Weechat.

Hacking A Rise images?q=tbn:ANd9GcQVkZlOZWEB1HS1UlRKUCjUJx4CgSZz36Z85p68qDmulTrGMKoLhw




Brief description of its usage:
You want to talk to your friends. But you don’t want the usual, boring, tame Calibri text. You want something new, something fresh. And don’t want your phone storage to be cramped by such fillers for the chatting app? Why not try the fancy, fast, light and extensible Weechat. It only needs 5MB. That is deeply low. If you want to waste some more storage then you can install the plugins.
Weechat is very easy to use and is very user-friendly. That is why I recommend it.
You can, of course, read more about it here.




Now, on to its usage:
First, install it via:
$ pkg install weechat
If you want, you can install the plugins too with:
$ pkg install weechat-lua-plugin
$ pkg install weechat-perl-plugin
$ pkg install weechat-python-plugin
$ pkg install weechat-ruby-plugin

Of course, this is optional. Meaning it’s ok to not install them.

Now, to use it is super easy:
Just type:
weechat
And now a new UI has opened.

You can notice that triggering your smartphone keyboard isn’t possible in the Weechat UI. So if you want to enable/disable the keyboard, swipe from left side of the screen to the right and press ‘KEYBOARD’.

Now that you know how to work the keyboard, you can now work with the commands. Attention: commands must always start with a forward slash a.k.a /. The basic commands that you need to know are:

/server add [NAME] [SERVER]
Servers don’t come generated by themselves in the Weechat list. That’s why you need to manually add them into the list via that command.

/server list
To list all avalible servers. You need to add them first.

/server del [NAME]
Erase a saved server from the list. This command is utilized when you make a typo while attempting to add a server to the list.

/connect [NAME or SERVER]
To connect to a server.
Specify NAME: means that you want to connect to a server with a saved name.
Specify SERVER: means that you want to connect to a server but you don’t want the server to be saved in list.

/list
List all channels in a server. After when you are connected of course.




/join [CHANNEL]
To join a channel after when you are connected to a server.
Attention: a channel name must have a hashtag (#) at the start to be considered valid.

That’s the basic commands. You can always view all commands in the help list via:
/help.
And see the basic syntax of a command by:
/help [COMMAND]

Weechat provide the touchscreen feature. Meaning that you can use your fingers to swipe the contents up or down, a.k.a scroll it.

Scripts can be used to enhance the experience. To open the script list, use:
/script
Look at the bar at the top, it will provide help. Scroll the bar left to right with F9 and F10.
Attention: You must install plugins in order for them to work. The plugin name must correspond to the script extension:
Example:
– Python plugin will enable scripts with .py extension
– Perl plugin will enable scripts with .pl extension
– Ruby plugin will enable scripts with .rb extension

You can set and modify the Weechat settings. To open the settings list, use:
/fset
Again, look at the top bar, it will provide help.
Attention: Be careful as you modify them. A wrong move might break the whole thing down and render it unusable unless you reinstall Weechat.




Here are a few IRC servers that I know:
EFNet – ssl.efnet.org
EsperNet – irc.esper.net
Freenode – chat.freenode.net
GameSurge – irc.gamesurge.net
IRCnet – open.ircnet.net
IRCSource – irc.ircsource.net
NetFuze – irc.netfuze.net
OFTC – irc.oftc.net
QuakeNet – irc.quakenet.org
Rizon – irc.rizon.net
SDF – irc.sdf.org

Fun fact: You can even run it via Proxychains-ng to increase anonymity.

Thank you for reading this tutorial. I hope you have a nice day.

Saturday, July 13, 2019

OpenSSL instruction: How to encypher and decypher files

Hello everyone~~~

This is IRISnoir from Hackingarise. Coming back with a Termux based tutorial. This time about OpenSSL, the encryption tool.

Hacking A Rise encrypt-file-openssl

Now, a brief description of it’s usage:
In this world, everyone has the right to privacy. But there are some people that just have to go look at your files. This is the reason why OpenSSL exists.

Now, we try it out:
First, you need to install the package via:
$ pkg install openssl-tool

Now, when it’s installed, you now need to type in:
$ openssl
To open the OpenSSL text interface.

Then, to view all cyphers and encryption algorithms, just type:
OpenSSL> help
It prints all avalible commands and algorithms.

As you can see, there are a ton of algorithms. So I’ll only put an example encryption. The cipher we are gonna use is: aes-256-cbc.

Fun fact: the algorithm that I’m showcasing, AES(Advanced Encryption Standard) is also the one used by the U.S. government to protect confidential files. You can read more about it here.

Now, you need to enter this command to see it’s usage and options:
OpenSSL> aes-256-cbc -help
I know, it’s very much to take in. But we are in this together.

Now, the encryption part. I’m gonna make this basic so you understand. Type in:
OpenSSL> aes-256-cbc -salt -iter 2048 -pbkdf2 -in filename.txt -out filename_encrypted.txt

I’m gonna break down the whole thing:

aes-256-cbc: Cypher algorithm: aes-256-cbc.

-salt: Salt the encryption, to make it harder for offenders to decrypt. You can read about what salting means here.

-iter: Specify iteration count

-pbkdf2: Use password-based key derivation function 2, also short for PBKDF2

-in filename.txt: Specify the file which you want to have their contents encrypted. In this case, the file is ‘filename.txt’

-out filename_encrypted.txt: Specify the file which you want to have the encrypted message outputted to. In this case, it’s ‘filename_encrypted.txt’

Now, we go to the decryption. Decryption command goes like this:
OpenSSL> aes-256-cbc -d -in filename_encrypted.txt -out filename_decrypted.txt

This is gonna be broken down too.

-d: Stands for decrypt.

-in filename_encrypted.txt: Specify encrypted file which you want to be decrypted. In this case, it’s name is ‘filename_encrypted.txt’

-out filename.txt: Specify the file which you want the decrypted message to be written to. In this case, it’s ‘filename.txt’

Now, that is the end of this tutorial. I hope you have a great time. I’ll see you later. Remember, these tutorials are meant for good. Hackingarise is not responsible for any of your malicious acts. Thank you.

Sunday, July 7, 2019

How to use Tshark - the brother of Wireshark

Hello everyone~~

This is IRISnoir from Hackingarise. Bringing to you a tutorial. Let’s get started.

Now, this tutorial’s gonna show you about the usage of Tshark

Hacking A Rise images?q=tbn:ANd9GcT63vAMNP-V6uJ9pCexCvgw0tLEbUBt0S2WzM1QO46sXURdF7zhUg
Now, a little description: Tshark is the brother of Wireshark. But, Tshark is only compatible on terminal mode while Wireshark can only be used in VNC mode (called wireshark-gtk).

Now, Tshark’s installation:
It is located at the root-repo so make sure you have it subscribed with:
$ pkg install root-repo
If done, you can install it with:
$ pkg install tshark

Because Tshark’s in the root-repo, it means it has something to do with rooting your device. So go and root your device if you expect this tool to be helpful.

Now, using it casually without root will just make it turn into a Random packet generator. It means it will generate 1000 packets for your eyes to enjoy. No actual reconnaissance.

But using root will give it an entire different sensation. What you need is a connected Wifi. Then do this:
tsudo tshark -i wlan0 --color
-i will let you specify interface. But we want to sniff the wifi, we use wlan0
--color will make it rainbow colorful like the wireshark so you can distinguish traffic better.

Upon activation, you will get to see the whole traffic of the wifi. Pretty exciting to see and monitor everyone’s action. Makes you the (kinda) boss and if you are nice, you can monitor and watch for hackers like a fellow security.

If you find anything incriminating like ARP requests flooding, DoS/DDoS attempt then you need to report or do something to be safe or protect users in the network.

You can watch the help page, man page to see what you can do. Like increasing verbosity.

I hope that this tutorial will help you. We do NOT encourage you to do malicious acts on innocent people. Hackingarise is NOT responsible for your acts. Thank you very much for reading.

Saturday, July 6, 2019

How to use traceroute in Termux.

Hello guys~~
This is IRISnoir. And I’ll be making this tutorial for yall.

This tutorial is about how to traceroute a remote IP through hops.

Hacking A Rise what-is-traceroute-tutorial-730x480
Now, how does this work? You may ask.
It traces the given IP by hopping from many devices/IP until it meets its target.

This tool is named ‘tracepath’. Located at the stable repository. You need to install it first then you can perform tracing.

$ pkg install tracepath

Then the commands are:

$ tracepath [IP or Domain name]

‘traceroute’ command can be a substitute or alias of the command tracepath. This does not differ from the procedure of the previous command.

Now, you can sit back and relax as it traces the given target.
Like this.

1: 192.168.1.2 (192.168.1.2) 0.550ms pmtu 1500
1: 192.168.1.1 (192.168.1.1) 1.694ms
1: 192.168.1.1 (192.168.1.1) 2.459ms
2: 192.168.1.1 (192.168.1.1) 1.927ms pmtu 1492
2: 100.101.0.2 (100.101.0.2) 4.615ms
3: 172.16.52.65 (172.16.52.65) 7.810ms
4: 172.16.70.1 (172.16.70.1) 7.465ms
5: no reply
6: 172.16.71.77 (172.16.71.77) 479.718ms
7: 10.255.10.25 (10.255.10.25) 12.859ms
8: localhost (27.68.237.133) 9.203ms asymm 9
9: localhost (27.68.236.162) 8.677ms asymm 8
10: 203.113.187.114 (203.113.187.114) 1017.228ms asymm 12
10: 203.113.187.114 (203.113.187.114) 32.727ms asymm 12
11: 202.78.225.162 (202.78.225.162) 222.114ms asymm 13
12: 120.72.117.90 (120.72.117.90) 11.963ms reached
Resume: pmtu 1492 hops 12 back 14

It shows the hops details, how many hops, name and IP, MTU, etc..

But there is no guaranteed success because when the IP/domain name is out of range or with other reasons, it will display no reply. It will then attempt to hop elsewhere. If it finds a place to continue, good for you. If it doesn’t, you can stop.

I hope you enjoy my tutorial and find this useful. If so, share it around. This is for educational purposes. Hackingarise is not responsible for your malicious acts. Thank you.

Tuesday, July 2, 2019

Termux Tutorial: IPtables (Part 3-2 - Tables explanation)

Hiii guyyyys~~
It’s me IRISnoir and coming with a vid. I hope you enjoy.

Termux Tutorial: IPtables (Part 3-1 - IPtables explanation)

Hi guys, this is IRISnoir bringing to you my latest vids. Today about IPtables.

Thursday, June 27, 2019

Termux Tutorial: IPtables (Part 2-4 - IPtables usage)

Aye guys, it’s me IRISnoir and made another part of the iptables tutorial. Hope you guys enjoy 🙂

Sunday, June 23, 2019

Termux Tutorial: IPtables (Part 2-3 - IPtables usage)

welcome to hacking a rise im X-termux (irisnoir )in this video i show you how to use iptables in termux

Saturday, June 22, 2019

Termux Tutorial: IPtables (Part 2-2 - IPtables usage)

welcome to hacking a rise in this video i show u how to set up IP tables

Termux Tutorial: IPtables (Part 2-1 - IPtables usage)

welcome to hacking a rise in this video i show u how to set up IP tables

Termux Tutorial:IPtables (Part 1 - Introduction to IPtables)

This video will teach you how to use IPtables in Termux like a boss

Termux Tutorial: arp-scan and arp-fingerprint

welcome to hacking a rise I am X-termux in this video i show u how to perform a arp scan and fingerprint in termux on android

Thursday, June 20, 2019

install nethunter on termux

welcome back to hacking a rise in this post im going to show you how to install nethunter the right way in termux with out any errors

what is termux

Termux is an Android terminal emulator and Linux environment app that works directly with no rooting or setup required. A minimal base system is installed automatically – additional packages are available using the APT package manager.

what is nethunter

Kali NetHunter is an Android ROM overlay that includes a mobile penetration testing platform. It is officially available for download on newer Nexus devices and the OnePlus One, as well as some Samsung Galaxy models. It also works unofficially on other phones

installing termux

download termux of the playstore here
then install hackers keyboard here

installing nethunter

to install nethunter first type pkg install curl -y
Now copy and paste this to termux
curl -LO https://raw.githubusercontent.com/Hax4us/Nethunter-InTermux/master/kalinethunter
Hacking A Rise Screenshot_20190620-023828-169x300

Now type chmod +x kalinethunter
Then ./kalinethunter let it download

Once done type startkali
Then you see root@kali its istallex net we app the keys
So type wget https://http.kali.org/kali/pool/main/k/kali-archive-keyring/kali-archive-keyring_2018.1_all.deb
Then apt install ./kali-archive-keyring_2018.1_all.deb
Hacking A Rise Screenshot_20190620-024359-169x300

there ya have it lads just apt-get install kali-linux-full and u got a full kali toolset inside your termux